aboutsummaryrefslogtreecommitdiff
path: root/odb/mssql/mssql-types.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'odb/mssql/mssql-types.hxx')
-rw-r--r--odb/mssql/mssql-types.hxx11
1 files changed, 6 insertions, 5 deletions
diff --git a/odb/mssql/mssql-types.hxx b/odb/mssql/mssql-types.hxx
index 2ce7940..caedda3 100644
--- a/odb/mssql/mssql-types.hxx
+++ b/odb/mssql/mssql-types.hxx
@@ -87,12 +87,10 @@ namespace odb
int_, // Buffer is a 4-byte integer.
bigint, // Buffer is an 8-byte integer.
- /*
- numeric, // Buffer is an SQL_NUMERIC_STRUCT.
+ decimal, // Buffer is a decimal struct (SQL_NUMERIC_STRUCT).
- smallmoney, // Buffer is a 4-byte integer (*10,000 value).
- money, // Buffer is an 8-byte integer (*10,000 value).
- */
+ smallmoney, // Buffer is a smallmoney struct (DBMONEY4).
+ money, // Buffer is a money struct (DBMONEY).
float4, // Buffer is a float.
float8, // Buffer is a double.
@@ -124,6 +122,9 @@ namespace odb
SQLLEN* size_ind; // Pointer to the size/inidicator variable.
SQLLEN capacity; // Buffer capacity. For string/binary parameters
// this value is also used as maximum column size.
+ // For decimal parameters it contains precision (p)
+ // and scale (s) encoded as (p * 100 + s). For float4
+ // and float8 it contains precision.
};
}
}